==> qccrypt-0.1-src.zip: ui_ccryptdialog.h <==
#ifndef UI_CCRYPTDIALOG_H
#define UI_CCRYPTDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QDialog>
#include <QtGui/QLabel>
#include <QtGui/QLineEdit>
#include <QtGui/QPushButton>
#include <QtGui/QTabWidget>
#include <QtGui/QWidget>

class Ui_CCryptDialog
{
public:
    QPushButton *aboutButton;
    QTabWidget *tabQccryptMode;
    QWidget *encryptionTab;
    QLabel *encryptPathLabel;
    QLabel *encryptSizeLabel;
    QLabel *encryptLastReadLabel;
    QLabel *encryptLastReadValueLabel;
    QLabel *encryptLastModLabel;
    QPushButton *encryptButton;
    QLineEdit *encryptFileNameEdit;
    QLabel *encryptPathValueLabel;
    QLabel *encryptSizeValueLabel;
    QLabel *encryptLastModValueLabel;
    QPushButton *encryptOpenFileNameButton;
    QLabel *encryptFileNameLabel;
    QWidget *decryptionTab;
    QLabel *decryptPathLabel;
    QLabel *decryptPathValueLabel;
    QLabel *decryptSizeLabel;
    QLabel *decryptSizeValueLabel;
    QLabel *decryptLastReadLabel;
    QLabel *decryptLastReadValueLabel;
    QLabel *decryptLastModLabel;
    QLabel *decryptLastModValueLabel;
    QLineEdit *decryptFileNameEdit;
    QPushButton *decryptButton;
    QPushButton *decryptOpenFileNameButton;
    QLabel *decryptFileNameLabel;
    QLabel *label_4;
    QLabel *label_3;

    void setupUi(QDialog *CCryptDialog)
    {
    CCryptDialog->setObjectName(QString::fromUtf8("CCryptDialog"));
    CCryptDialog->resize(QSize(391, 404).expandedTo(CCryptDialog->minimumSizeHint()));
    CCryptDialog->setWindowIcon(QIcon(QString::fromUtf8("ressources/images/qccrypt.png")));
    aboutButton = new QPushButton(CCryptDialog);
    aboutButton->setObjectName(QString::fromUtf8("aboutButton"));
    aboutButton->setGeometry(QRect(338, 1, 51, 23));
    tabQccryptMode = new QTabWidget(CCryptDialog);
    tabQccryptMode->setObjectName(QString::fromUtf8("tabQccryptMode"));
    tabQccryptMode->setGeometry(QRect(10, 30, 371, 341));
    encryptionTab = new QWidget();
    encryptionTab->setObjectName(QString::fromUtf8("encryptionTab"));
    encryptPathLabel = new QLabel(encryptionTab);
    encryptPathLabel->setObjectName(QString::fromUtf8("encryptPathLabel"));
    encryptPathLabel->setGeometry(QRect(10, 60, 46, 14));
    encryptSizeLabel = new QLabel(encryptionTab);
    encryptSizeLabel->setObjectName(QString::fromUtf8("encryptSizeLabel"));
    encryptSizeLabel->setGeometry(QRect(10, 110, 46, 14));
    encryptLastReadLabel = new QLabel(encryptionTab);
    encryptLastReadLabel->setObjectName(QString::fromUtf8("encryptLastReadLabel"));
    encryptLastReadLabel->setGeometry(QRect(10, 160, 51, 16));
    encryptLastReadValueLabel = new QLabel(encryptionTab);
    encryptLastReadValueLabel->setObjectName(QString::fromUtf8("encryptLastReadValueLabel"));
    encryptLastReadValueLabel->setGeometry(QRect(10, 180, 301, 20));
    encryptLastReadValueLabel->setFrameShape(QFrame::Panel);
    encryptLastReadValueLabel->setFrameShadow(QFrame::Sunken);
    encryptLastModLabel = new QLabel(encryptionTab);
    encryptLastModLabel->setObjectName(QString::fromUtf8("encryptLastModLabel"));
    encryptLastModLabel->setGeometry(QRect(10, 210, 71, 16));
    encryptLastModLabel->setFrameShape(QFrame::NoFrame);
    encryptLastModLabel->setFrameShadow(QFrame::Plain);
    encryptButton = new QPushButton(encryptionTab);
    encryptButton->setObjectName(QString::fromUtf8("encryptButton"));
    encryptButton->setGeometry(QRect(140, 270, 75, 23));
    encryptFileNameEdit = new QLineEdit(encryptionTab);
    encryptFileNameEdit->setObjectName(QString::fromUtf8("encryptFileNameEdit"));
    encryptFileNameEdit->setEnabled(false);
    encryptFileNameEdit->setGeometry(QRect(10, 30, 301, 20));
    encryptPathValueLabel = new QLabel(encryptionTab);
    encryptPathValueLabel->setObjectName(QString::fromUtf8("encryptPathValueLabel"));
    encryptPathValueLabel->setGeometry(QRect(10, 76, 301, 20));
    encryptPathValueLabel->setFrameShape(QFrame::Panel);
    encryptPathValueLabel->setFrameShadow(QFrame::Sunken);
    encryptSizeValueLabel = new QLabel(encryptionTab);
    encryptSizeValueLabel->setObjectName(QString::fromUtf8("encryptSizeValueLabel"));
    encryptSizeValueLabel->setGeometry(QRect(10, 126, 301, 20));
    encryptSizeValueLabel->setFrameShape(QFrame::Panel);
    encryptSizeValueLabel->setFrameShadow(QFrame::Sunken);
    encryptLastModValueLabel = new QLabel(encryptionTab);
    encryptLastModValueLabel->setObjectName(QString::fromUtf8("encryptLastModValueLabel"));
    encryptLastModValueLabel->setGeometry(QRect(10, 234, 301, 20));
    encryptLastModValueLabel->setFrameShape(QFrame::Panel);
    encryptLastModValueLabel->setFrameShadow(QFrame::Sunken);
    encryptOpenFileNameButton = new QPushButton(encryptionTab);
    encryptOpenFileNameButton->setObjectName(QString::fromUtf8("encryptOpenFileNameButton"));
    encryptOpenFileNameButton->setGeometry(QRect(320, 30, 31, 23));
    encryptFileNameLabel = new QLabel(encryptionTab);
    encryptFileNameLabel->setObjectName(QString::fromUtf8("encryptFileNameLabel"));
    encryptFileNameLabel->setGeometry(QRect(10, 10, 81, 16));
    tabQccryptMode->addTab(encryptionTab, QApplication::translate("CCryptDialog", "Encryption", 0, QApplication::UnicodeUTF8));
    decryptionTab = new QWidget();
    decryptionTab->setObjectName(QString::fromUtf8("decryptionTab"));
    decryptPathLabel = new QLabel(decryptionTab);
    decryptPathLabel->setObjectName(QString::fromUtf8("decryptPathLabel"));
    decryptPathLabel->setGeometry(QRect(10, 60, 46, 14));
    decryptPathValueLabel = new QLabel(decryptionTab);
    decryptPathValueLabel->setObjectName(QString::fromUtf8("decryptPathValueLabel"));
    decryptPathValueLabel->setGeometry(QRect(10, 76, 301, 20));
    decryptPathValueLabel->setFrameShape(QFrame::Panel);
    decryptPathValueLabel->setFrameShadow(QFrame::Sunken);
    decryptSizeLabel = new QLabel(decryptionTab);
    decryptSizeLabel->setObjectName(QString::fromUtf8("decryptSizeLabel"));
    decryptSizeLabel->setGeometry(QRect(10, 110, 46, 14));
    decryptSizeValueLabel = new QLabel(decryptionTab);
    decryptSizeValueLabel->setObjectName(QString::fromUtf8("decryptSizeValueLabel"));
    decryptSizeValueLabel->setGeometry(QRect(10, 126, 301, 20));
    decryptSizeValueLabel->setFrameShape(QFrame::Panel);
    decryptSizeValueLabel->setFrameShadow(QFrame::Sunken);
    decryptLastReadLabel = new QLabel(decryptionTab);
    decryptLastReadLabel->setObjectName(QString::fromUtf8("decryptLastReadLabel"));
    decryptLastReadLabel->setGeometry(QRect(10, 160, 51, 16));
    decryptLastReadValueLabel = new QLabel(decryptionTab);
    decryptLastReadValueLabel->setObjectName(QString::fromUtf8("decryptLastReadValueLabel"));
    decryptLastReadValueLabel->setGeometry(QRect(10, 180, 301, 20));
    decryptLastReadValueLabel->setFrameShape(QFrame::Panel);
    decryptLastReadValueLabel->setFrameShadow(QFrame::Sunken);
    decryptLastModLabel = new QLabel(decryptionTab);
    decryptLastModLabel->setObjectName(QString::fromUtf8("decryptLastModLabel"));
    decryptLastModLabel->setGeometry(QRect(10, 210, 71, 16));
    decryptLastModLabel->setFrameShape(QFrame::NoFrame);
    decryptLastModLabel->setFrameShadow(QFrame::Plain);
    decryptLastModValueLabel = new QLabel(decryptionTab);
    decryptLastModValueLabel->setObjectName(QString::fromUtf8("decryptLastModValueLabel"));
    decryptLastModValueLabel->setGeometry(QRect(10, 234, 301, 20));
    decryptLastModValueLabel->setFrameShape(QFrame::Panel);
    decryptLastModValueLabel->setFrameShadow(QFrame::Sunken);
    decryptFileNameEdit = new QLineEdit(decryptionTab);
    decryptFileNameEdit->setObjectName(QString::fromUtf8("decryptFileNameEdit"));
    decryptFileNameEdit->setEnabled(false);
    decryptFileNameEdit->setGeometry(QRect(10, 30, 301, 20));
    decryptButton = new QPushButton(decryptionTab);
    decryptButton->setObjectName(QString::fromUtf8("decryptButton"));
    decryptButton->setGeometry(QRect(140, 270, 75, 23));
    decryptOpenFileNameButton = new QPushButton(decryptionTab);
    decryptOpenFileNameButton->setObjectName(QString::fromUtf8("decryptOpenFileNameButton"));
    decryptOpenFileNameButton->setGeometry(QRect(320, 30, 31, 23));
    decryptFileNameLabel = new QLabel(decryptionTab);
    decryptFileNameLabel->setObjectName(QString::fromUtf8("decryptFileNameLabel"));
    decryptFileNameLabel->setGeometry(QRect(10, 10, 81, 16));
    tabQccryptMode->addTab(decryptionTab, QApplication::translate("CCryptDialog", "Decryption", 0, QApplication::UnicodeUTF8));
    label_4 = new QLabel(CCryptDialog);
    label_4->setObjectName(QString::fromUtf8("label_4"));
    label_4->setGeometry(QRect(140, 378, 111, 16));
    label_4->setFrameShape(QFrame::NoFrame);
    label_4->setFrameShadow(QFrame::Plain);
    label_3 = new QLabel(CCryptDialog);
    label_3->setObjectName(QString::fromUtf8("label_3"));
    label_3->setGeometry(QRect(80, 2, 201, 20));
    label_3->setFrameShape(QFrame::NoFrame);
    label_3->setFrameShadow(QFrame::Plain);
    retranslateUi(CCryptDialog);

    tabQccryptMode->setCurrentIndex(0);


    QMetaObject::connectSlotsByName(CCryptDialog);
    } // setupUi

    void retranslateUi(QDialog *CCryptDialog)
    {
    CCryptDialog->setWindowTitle(QApplication::translate("CCryptDialog", "Qccrypt 0.1", 0, QApplication::UnicodeUTF8));
    aboutButton->setText(QApplication::translate("CCryptDialog", "About", 0, QApplication::UnicodeUTF8));
    encryptPathLabel->setText(QApplication::translate("CCryptDialog", "Path", 0, QApplication::UnicodeUTF8));
    encryptSizeLabel->setText(QApplication::translate("CCryptDialog", "Size", 0, QApplication::UnicodeUTF8));
    encryptLastReadLabel->setText(QApplication::translate("CCryptDialog", "Last Read", 0, QApplication::UnicodeUTF8));
    encryptLastReadValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    encryptLastModLabel->setText(QApplication::translate("CCryptDialog", "Last Modified", 0, QApplication::UnicodeUTF8));
    encryptButton->setText(QApplication::translate("CCryptDialog", "Encrypt File", 0, QApplication::UnicodeUTF8));
    encryptPathValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    encryptSizeValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    encryptLastModValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    encryptOpenFileNameButton->setText(QApplication::translate("CCryptDialog", "...", 0, QApplication::UnicodeUTF8));
    encryptFileNameLabel->setText(QApplication::translate("CCryptDialog", "File to encrypt :", 0, QApplication::UnicodeUTF8));
    tabQccryptMode->setTabText(tabQccryptMode->indexOf(encryptionTab), QApplication::translate("CCryptDialog", "Encryption", 0, QApplication::UnicodeUTF8));
    decryptPathLabel->setText(QApplication::translate("CCryptDialog", "Path", 0, QApplication::UnicodeUTF8));
    decryptPathValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    decryptSizeLabel->setText(QApplication::translate("CCryptDialog", "Size", 0, QApplication::UnicodeUTF8));
    decryptSizeValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    decryptLastReadLabel->setText(QApplication::translate("CCryptDialog", "Last Read", 0, QApplication::UnicodeUTF8));
    decryptLastReadValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    decryptLastModLabel->setText(QApplication::translate("CCryptDialog", "Last Modified", 0, QApplication::UnicodeUTF8));
    decryptLastModValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    decryptButton->setText(QApplication::translate("CCryptDialog", "Decrypt File", 0, QApplication::UnicodeUTF8));
    decryptOpenFileNameButton->setText(QApplication::translate("CCryptDialog", "...", 0, QApplication::UnicodeUTF8));
    decryptFileNameLabel->setText(QApplication::translate("CCryptDialog", "File to decrypt :", 0, QApplication::UnicodeUTF8));
    tabQccryptMode->setTabText(tabQccryptMode->indexOf(decryptionTab), QApplication::translate("CCryptDialog", "Decryption", 0, QApplication::UnicodeUTF8));
    label_4->setText(QApplication::translate("CCryptDialog", "http://qccrypt.free.fr/", 0, QApplication::UnicodeUTF8));
    label_3->setText(QApplication::translate("CCryptDialog", "Qccrypt is written by Philippe Beaureilles", 0, QApplication::UnicodeUTF8));
    Q_UNUSED(CCryptDialog);
    } // retranslateUi

};

namespace Ui {
    class CCryptDialog: public Ui_CCryptDialog {};
} // namespace Ui

#endif // UI_CCRYPTDIALOG_H

==> qccrypt-0.1.2-src.zip: ui_ccryptdialog.h <==
#ifndef UI_CCRYPTDIALOG_H
#define UI_CCRYPTDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QDialog>
#include <QtGui/QLabel>
#include <QtGui/QLineEdit>
#include <QtGui/QPushButton>
#include <QtGui/QTabWidget>
#include <QtGui/QWidget>

class Ui_CCryptDialog
{
public:
    QPushButton *aboutButton;
    QLabel *label_3;
    QLabel *label_4;
    QTabWidget *tabQccryptMode;
    QWidget *encryptionTab;
    QLabel *encryptPathLabel;
    QLabel *encryptSizeLabel;
    QLabel *encryptLastReadValueLabel;
    QLineEdit *encryptFileNameEdit;
    QLabel *encryptPathValueLabel;
    QLabel *encryptSizeValueLabel;
    QLabel *encryptLastModValueLabel;
    QPushButton *encryptOpenFileNameButton;
    QLabel *encryptFileNameLabel;
    QLabel *encryptLastReadLabel;
    QLabel *encryptLastModLabel;
    QPushButton *encryptButton;
    QWidget *decryptionTab;
    QLabel *decryptPathLabel;
    QLabel *decryptPathValueLabel;
    QLabel *decryptSizeLabel;
    QLabel *decryptSizeValueLabel;
    QLabel *decryptLastReadValueLabel;
    QLabel *decryptLastModValueLabel;
    QLineEdit *decryptFileNameEdit;
    QPushButton *decryptOpenFileNameButton;
    QLabel *decryptFileNameLabel;
    QLabel *decryptLastReadLabel;
    QLabel *decryptLastModLabel;
    QPushButton *decryptButton;

    void setupUi(QDialog *CCryptDialog)
    {
    CCryptDialog->setObjectName(QString::fromUtf8("CCryptDialog"));
    CCryptDialog->resize(QSize(391, 404).expandedTo(CCryptDialog->minimumSizeHint()));
    CCryptDialog->setWindowIcon(QIcon(QString::fromUtf8(":/ressources/images/qccrypt.png")));
    aboutButton = new QPushButton(CCryptDialog);
    aboutButton->setObjectName(QString::fromUtf8("aboutButton"));
    aboutButton->setGeometry(QRect(338, 1, 51, 23));
    label_3 = new QLabel(CCryptDialog);
    label_3->setObjectName(QString::fromUtf8("label_3"));
    label_3->setGeometry(QRect(64, 2, 261, 20));
    label_3->setFrameShape(QFrame::NoFrame);
    label_3->setFrameShadow(QFrame::Plain);
    label_4 = new QLabel(CCryptDialog);
    label_4->setObjectName(QString::fromUtf8("label_4"));
    label_4->setGeometry(QRect(130, 380, 130, 17));
    label_4->setFrameShape(QFrame::NoFrame);
    label_4->setFrameShadow(QFrame::Plain);
    tabQccryptMode = new QTabWidget(CCryptDialog);
    tabQccryptMode->setObjectName(QString::fromUtf8("tabQccryptMode"));
    tabQccryptMode->setGeometry(QRect(10, 30, 371, 341));
    encryptionTab = new QWidget();
    encryptionTab->setObjectName(QString::fromUtf8("encryptionTab"));
    encryptPathLabel = new QLabel(encryptionTab);
    encryptPathLabel->setObjectName(QString::fromUtf8("encryptPathLabel"));
    encryptPathLabel->setGeometry(QRect(10, 60, 46, 14));
    encryptSizeLabel = new QLabel(encryptionTab);
    encryptSizeLabel->setObjectName(QString::fromUtf8("encryptSizeLabel"));
    encryptSizeLabel->setGeometry(QRect(10, 110, 46, 14));
    encryptLastReadValueLabel = new QLabel(encryptionTab);
    encryptLastReadValueLabel->setObjectName(QString::fromUtf8("encryptLastReadValueLabel"));
    encryptLastReadValueLabel->setGeometry(QRect(10, 180, 301, 20));
    encryptLastReadValueLabel->setFrameShape(QFrame::Panel);
    encryptLastReadValueLabel->setFrameShadow(QFrame::Sunken);
    encryptFileNameEdit = new QLineEdit(encryptionTab);
    encryptFileNameEdit->setObjectName(QString::fromUtf8("encryptFileNameEdit"));
    encryptFileNameEdit->setEnabled(false);
    encryptFileNameEdit->setGeometry(QRect(10, 30, 301, 20));
    encryptPathValueLabel = new QLabel(encryptionTab);
    encryptPathValueLabel->setObjectName(QString::fromUtf8("encryptPathValueLabel"));
    encryptPathValueLabel->setGeometry(QRect(10, 76, 301, 20));
    encryptPathValueLabel->setFrameShape(QFrame::Panel);
    encryptPathValueLabel->setFrameShadow(QFrame::Sunken);
    encryptSizeValueLabel = new QLabel(encryptionTab);
    encryptSizeValueLabel->setObjectName(QString::fromUtf8("encryptSizeValueLabel"));
    encryptSizeValueLabel->setGeometry(QRect(10, 126, 301, 20));
    encryptSizeValueLabel->setFrameShape(QFrame::Panel);
    encryptSizeValueLabel->setFrameShadow(QFrame::Sunken);
    encryptLastModValueLabel = new QLabel(encryptionTab);
    encryptLastModValueLabel->setObjectName(QString::fromUtf8("encryptLastModValueLabel"));
    encryptLastModValueLabel->setGeometry(QRect(10, 234, 301, 20));
    encryptLastModValueLabel->setFrameShape(QFrame::Panel);
    encryptLastModValueLabel->setFrameShadow(QFrame::Sunken);
    encryptOpenFileNameButton = new QPushButton(encryptionTab);
    encryptOpenFileNameButton->setObjectName(QString::fromUtf8("encryptOpenFileNameButton"));
    encryptOpenFileNameButton->setGeometry(QRect(320, 30, 31, 23));
    encryptFileNameLabel = new QLabel(encryptionTab);
    encryptFileNameLabel->setObjectName(QString::fromUtf8("encryptFileNameLabel"));
    encryptFileNameLabel->setGeometry(QRect(10, 10, 111, 17));
    encryptLastReadLabel = new QLabel(encryptionTab);
    encryptLastReadLabel->setObjectName(QString::fromUtf8("encryptLastReadLabel"));
    encryptLastReadLabel->setGeometry(QRect(10, 160, 71, 17));
    encryptLastModLabel = new QLabel(encryptionTab);
    encryptLastModLabel->setObjectName(QString::fromUtf8("encryptLastModLabel"));
    encryptLastModLabel->setGeometry(QRect(10, 210, 91, 17));
    encryptLastModLabel->setFrameShape(QFrame::NoFrame);
    encryptLastModLabel->setFrameShadow(QFrame::Plain);
    encryptButton = new QPushButton(encryptionTab);
    encryptButton->setObjectName(QString::fromUtf8("encryptButton"));
    encryptButton->setGeometry(QRect(134, 270, 81, 23));
    tabQccryptMode->addTab(encryptionTab, QApplication::translate("CCryptDialog", "Encryption", 0, QApplication::UnicodeUTF8));
    decryptionTab = new QWidget();
    decryptionTab->setObjectName(QString::fromUtf8("decryptionTab"));
    decryptPathLabel = new QLabel(decryptionTab);
    decryptPathLabel->setObjectName(QString::fromUtf8("decryptPathLabel"));
    decryptPathLabel->setGeometry(QRect(10, 60, 46, 14));
    decryptPathValueLabel = new QLabel(decryptionTab);
    decryptPathValueLabel->setObjectName(QString::fromUtf8("decryptPathValueLabel"));
    decryptPathValueLabel->setGeometry(QRect(10, 76, 301, 20));
    decryptPathValueLabel->setFrameShape(QFrame::Panel);
    decryptPathValueLabel->setFrameShadow(QFrame::Sunken);
    decryptSizeLabel = new QLabel(decryptionTab);
    decryptSizeLabel->setObjectName(QString::fromUtf8("decryptSizeLabel"));
    decryptSizeLabel->setGeometry(QRect(10, 110, 46, 14));
    decryptSizeValueLabel = new QLabel(decryptionTab);
    decryptSizeValueLabel->setObjectName(QString::fromUtf8("decryptSizeValueLabel"));
    decryptSizeValueLabel->setGeometry(QRect(10, 126, 301, 20));
    decryptSizeValueLabel->setFrameShape(QFrame::Panel);
    decryptSizeValueLabel->setFrameShadow(QFrame::Sunken);
    decryptLastReadValueLabel = new QLabel(decryptionTab);
    decryptLastReadValueLabel->setObjectName(QString::fromUtf8("decryptLastReadValueLabel"));
    decryptLastReadValueLabel->setGeometry(QRect(10, 180, 301, 20));
    decryptLastReadValueLabel->setFrameShape(QFrame::Panel);
    decryptLastReadValueLabel->setFrameShadow(QFrame::Sunken);
    decryptLastModValueLabel = new QLabel(decryptionTab);
    decryptLastModValueLabel->setObjectName(QString::fromUtf8("decryptLastModValueLabel"));
    decryptLastModValueLabel->setGeometry(QRect(10, 234, 301, 20));
    decryptLastModValueLabel->setFrameShape(QFrame::Panel);
    decryptLastModValueLabel->setFrameShadow(QFrame::Sunken);
    decryptFileNameEdit = new QLineEdit(decryptionTab);
    decryptFileNameEdit->setObjectName(QString::fromUtf8("decryptFileNameEdit"));
    decryptFileNameEdit->setEnabled(false);
    decryptFileNameEdit->setGeometry(QRect(10, 30, 301, 20));
    decryptOpenFileNameButton = new QPushButton(decryptionTab);
    decryptOpenFileNameButton->setObjectName(QString::fromUtf8("decryptOpenFileNameButton"));
    decryptOpenFileNameButton->setGeometry(QRect(320, 30, 31, 23));
    decryptFileNameLabel = new QLabel(decryptionTab);
    decryptFileNameLabel->setObjectName(QString::fromUtf8("decryptFileNameLabel"));
    decryptFileNameLabel->setGeometry(QRect(10, 10, 111, 17));
    decryptLastReadLabel = new QLabel(decryptionTab);
    decryptLastReadLabel->setObjectName(QString::fromUtf8("decryptLastReadLabel"));
    decryptLastReadLabel->setGeometry(QRect(10, 160, 81, 17));
    decryptLastModLabel = new QLabel(decryptionTab);
    decryptLastModLabel->setObjectName(QString::fromUtf8("decryptLastModLabel"));
    decryptLastModLabel->setGeometry(QRect(10, 210, 101, 17));
    decryptLastModLabel->setFrameShape(QFrame::NoFrame);
    decryptLastModLabel->setFrameShadow(QFrame::Plain);
    decryptButton = new QPushButton(decryptionTab);
    decryptButton->setObjectName(QString::fromUtf8("decryptButton"));
    decryptButton->setGeometry(QRect(124, 270, 91, 23));
    tabQccryptMode->addTab(decryptionTab, QApplication::translate("CCryptDialog", "Decryption", 0, QApplication::UnicodeUTF8));
    retranslateUi(CCryptDialog);

    tabQccryptMode->setCurrentIndex(0);


    QMetaObject::connectSlotsByName(CCryptDialog);
    } // setupUi

    void retranslateUi(QDialog *CCryptDialog)
    {
    CCryptDialog->setWindowTitle(QApplication::translate("CCryptDialog", "Qccrypt 0.1.2", 0, QApplication::UnicodeUTF8));
    aboutButton->setText(QApplication::translate("CCryptDialog", "About", 0, QApplication::UnicodeUTF8));
    label_3->setText(QApplication::translate("CCryptDialog", "Qccrypt is written by Philippe Beaureilles", 0, QApplication::UnicodeUTF8));
    label_4->setText(QApplication::translate("CCryptDialog", "http://qccrypt.free.fr/", 0, QApplication::UnicodeUTF8));
    encryptPathLabel->setText(QApplication::translate("CCryptDialog", "Path", 0, QApplication::UnicodeUTF8));
    encryptSizeLabel->setText(QApplication::translate("CCryptDialog", "Size", 0, QApplication::UnicodeUTF8));
    encryptLastReadValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    encryptPathValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    encryptSizeValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    encryptLastModValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    encryptOpenFileNameButton->setText(QApplication::translate("CCryptDialog", "...", 0, QApplication::UnicodeUTF8));
    encryptFileNameLabel->setText(QApplication::translate("CCryptDialog", "File to encrypt :", 0, QApplication::UnicodeUTF8));
    encryptLastReadLabel->setText(QApplication::translate("CCryptDialog", "Last Read", 0, QApplication::UnicodeUTF8));
    encryptLastModLabel->setText(QApplication::translate("CCryptDialog", "Last Modified", 0, QApplication::UnicodeUTF8));
    encryptButton->setText(QApplication::translate("CCryptDialog", "Encrypt File", 0, QApplication::UnicodeUTF8));
    tabQccryptMode->setTabText(tabQccryptMode->indexOf(encryptionTab), QApplication::translate("CCryptDialog", "Encryption", 0, QApplication::UnicodeUTF8));
    decryptPathLabel->setText(QApplication::translate("CCryptDialog", "Path", 0, QApplication::UnicodeUTF8));
    decryptPathValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    decryptSizeLabel->setText(QApplication::translate("CCryptDialog", "Size", 0, QApplication::UnicodeUTF8));
    decryptSizeValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    decryptLastReadValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    decryptLastModValueLabel->setText(QApplication::translate("CCryptDialog", "", 0, QApplication::UnicodeUTF8));
    decryptOpenFileNameButton->setText(QApplication::translate("CCryptDialog", "...", 0, QApplication::UnicodeUTF8));
    decryptFileNameLabel->setText(QApplication::translate("CCryptDialog", "File to decrypt :", 0, QApplication::UnicodeUTF8));
    decryptLastReadLabel->setText(QApplication::translate("CCryptDialog", "Last Read", 0, QApplication::UnicodeUTF8));
    decryptLastModLabel->setText(QApplication::translate("CCryptDialog", "Last Modified", 0, QApplication::UnicodeUTF8));
    decryptButton->setText(QApplication::translate("CCryptDialog", "Decrypt File", 0, QApplication::UnicodeUTF8));
    tabQccryptMode->setTabText(tabQccryptMode->indexOf(decryptionTab), QApplication::translate("CCryptDialog", "Decryption", 0, QApplication::UnicodeUTF8));
    Q_UNUSED(CCryptDialog);
    } // retranslateUi

};

namespace Ui {
    class CCryptDialog: public Ui_CCryptDialog {};
} // namespace Ui

#endif // UI_CCRYPTDIALOG_H
